CancelLocalUpdateUnit

Struct CancelLocalUpdateUnit 

pub struct CancelLocalUpdateUnit;
Remove (cancel) a fragment from an authority, setting the fragment to unit.

This requires the fragment to remove to be cancelable.